Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(69)

Unified Diff: test/Driver/asmjs-unknown-emscripten.cpp

Issue 1022123003: clang: add support for asmjs arch and Emscripten OS (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-clang.git@master
Patch Set: Address comments. Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/CodeGenCXX/static-init-emscripten.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/Driver/asmjs-unknown-emscripten.cpp
diff --git a/test/Driver/le32-unknown-nacl.cpp b/test/Driver/asmjs-unknown-emscripten.cpp
similarity index 80%
copy from test/Driver/le32-unknown-nacl.cpp
copy to test/Driver/asmjs-unknown-emscripten.cpp
index 379ddb6c63d82c764bbb89daaef786b8a0a7ebe6..8a8df4c9fed2abce5863990f477155a764417f8e 100644
--- a/test/Driver/le32-unknown-nacl.cpp
+++ b/test/Driver/asmjs-unknown-emscripten.cpp
@@ -1,8 +1,8 @@
// RUN: %clang -target le32-unknown-nacl -### %s -emit-llvm-only -c 2>&1 | FileCheck %s -check-prefix=ECHO
// RUN: %clang -target le32-unknown-nacl %s -emit-llvm -S -c -o - | FileCheck %s
// RUN: %clang -target le32-unknown-nacl %s -emit-llvm -S -c -pthread -o - | FileCheck %s -check-prefix=THREADS
// ECHO: {{.*}} "-cc1" {{.*}}le32-unknown-nacl.c
typedef __builtin_va_list va_list;
typedef __SIZE_TYPE__ size_t;
@@ -45,19 +45,19 @@ int align_vl = __alignof(va_list);
void __LITTLE_ENDIAN__defined() {}
#endif
-// CHECK: __native_client__defined
-#ifdef __native_client__
-void __native_client__defined() {}
+// CHECK: __asmjs__defined
+#ifdef __asmjs__
+void __asmjs__defined() {}
#endif
-// CHECK: __le32__defined
-#ifdef __le32__
-void __le32__defined() {}
+// CHECK: EMSCRIPTENdefined
+#ifdef EMSCRIPTEN
+void EMSCRIPTENdefined() {}
#endif
-// CHECK: __pnacl__defined
-#ifdef __pnacl__
-void __pnacl__defined() {}
+// CHECK: __EMSCRIPTEN__defined
+#ifdef __EMSCRIPTEN__
+void __EMSCRIPTEN__defined() {}
#endif
// CHECK: unixdefined
@@ -65,11 +65,6 @@ void __pnacl__defined() {}
void unixdefined() {}
#endif
-// CHECK: __ELF__defined
-#ifdef __ELF__
-void __ELF__defined() {}
-#endif
-
// CHECK: _GNU_SOURCEdefined
#ifdef _GNU_SOURCE
void _GNU_SOURCEdefined() {}
@@ -1,8 +1,8 @@
-// RUN: %clang -target le32-unknown-nacl -### %s -emit-llvm-only -c 2>&1 | FileCheck %s -check-prefix=ECHO
-// RUN: %clang -target le32-unknown-nacl %s -emit-llvm -S -c -o - | FileCheck %s
-// RUN: %clang -target le32-unknown-nacl %s -emit-llvm -S -c -pthread -o - | FileCheck %s -check-prefix=THREADS
+// RUN: %clang -target asmjs-unknown-emscripten -### %s -emit-llvm-only -c 2>&1 | FileCheck %s -check-prefix=ECHO
+// RUN: %clang -target asmjs-unknown-emscripten %s -emit-llvm -S -c -o - | FileCheck %s
+// RUN: %clang -target asmjs-unknown-emscripten %s -emit-llvm -S -c -pthread -o - | FileCheck %s -check-prefix=THREADS
-// ECHO: {{.*}} "-cc1" {{.*}}le32-unknown-nacl.c
+// ECHO: {{.*}} "-cc1" {{.*}}asmjs-unknown-emscripten.c
typedef __builtin_va_list va_list;
typedef __SIZE_TYPE__ size_t;
« no previous file with comments | « test/CodeGenCXX/static-init-emscripten.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698